@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-a2i-runtime service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/literals.html)
 
 Usage::
 
@@ -24,9 +24,7 @@ __all__ = (
     "HumanLoopStatusType",
     "ListHumanLoopsPaginatorName",
     "SortOrderType",
-    "AugmentedAIRuntimeServiceName",
     "ServiceName",
-    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -35,7 +33,6 @@ ContentClassifierType = Literal["FreeOfAdultContent", "FreeOfPersonallyIdentifia
 HumanLoopStatusType = Literal["Completed", "Failed", "InProgress", "Stopped", "Stopping"]
 ListHumanLoopsPaginatorName = Literal["list_human_loops"]
 SortOrderType = Literal["Ascending", "Descending"]
-AugmentedAIRuntimeServiceName = Literal["sagemaker-a2i-runtime"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -324,16 +321,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal["list_human_loops"]
